@@ -602,7 +602,6 @@ class SurfingEntrance(object):
         nav_analysis.init(str_end_date)
 
         failed_factors.extend(nav_analysis.process_fund_ret())
-        failed_factors.extend(nav_analysis.process_current_mdd())
         failed_factors.extend(nav_analysis.process_monthly_ret())
         failed_factors.extend(nav_analysis.process_period_ret())
         failed_factors.extend(nav_analysis.process_recent_ret())
@@ -725,10 +724,11 @@ class SurfingEntrance(object):
     def pull_hedge_fund_nav(self):
         from .data.manager.manager_fof import FOFDataManager
 
+        MANAGER_ID = 'py1'
         FOF_ID = 'SLW695'
 
         fof_dm = FOFDataManager()
-        fof_dm.pull_hedge_fund_nav(fof_id=FOF_ID)
+        fof_dm.pull_hedge_fund_nav(manager_id=MANAGER_ID, fof_id=FOF_ID)
 
 
 if __name__ == "__main__":
