@@ -1883,7 +1883,7 @@ class BasicDataApi(metaclass=Singleton):
                     '由生产成本、利润和税金三部分组成，它是工业产品进入流通领域的最初价格。',
                     '指数比预期数值高时，表明有通货膨胀的风险；指数比预期数值低时，则表明有通货紧缩的风险。']
             data = {
-                '工业品出场PPI':df,
+                'data':df,
                 '沪深300总增长':index_ret,
                 '介绍':text,
             }
@@ -1911,7 +1911,7 @@ class BasicDataApi(metaclass=Singleton):
                     'PMI指数50为荣枯分水线。PMI略大于50，说明经济在缓慢前进，PMI略小于50说明经济在慢慢走向衰退。']
             data = {
                 'data':df,
-                'text':text,
+                '介绍':text,
             }
             return data
         except Exception as e:
@@ -1975,26 +1975,39 @@ class BasicDataApi(metaclass=Singleton):
             index_price = index_price.pivot_table(index='datetime',values='close',columns='index_id')
             index_price = index_price.reindex(index_price.index.union(df.index).sort_values()).ffill()
             df = df.join(index_price).dropna().rename(columns={'hs300':'沪深300'})
-            return df
+            return df.round(2)
         except Exception as e:
             print(f'Failed to get data <err_msg> {e} from basic.get_cpi')
             return pd.DataFrame([])
 
-    def get_ah_prem(self, begin_date, end_date, time_para):
+    def get_ah_prem(self, begin_date, end_date, time_para, frequency):
         try:
             raw = RawDataApi()
             index_id = 'em_ah_prem'
             begin_date, end_date = raw.get_date_range(time_para, begin_date, end_date)
             index_price = BasicDataApi().get_index_price_dt(start_date=begin_date,end_date=end_date,index_list=[index_id])
-            index_price = index_price.pivot_table(index='datetime',values='close',columns='index_id')
-            index_price = index_price.rename(columns={index_id:'AH股溢价指数'})
-            return index_price
+            index_price = index_price.set_index('datetime')[['open','high','low','close']]
+            title = 'AH股溢价指数'
+            if frequency != '1D':
+                index_price = index_price.set_axis(pd.to_datetime(index_price.index), inplace=False).resample(frequency).last()
+                index_price.index = [i.date() for i in index_price.index]
+                index_price.index.name = 'datetime'
+            
+            index_price.loc[:,'MA5'] = index_price.close.rolling(window=5,min_periods=1).mean() 
+            index_price.loc[:,'MA10'] = index_price.close.rolling(window=10,min_periods=1).mean() 
+            index_price.loc[:,'MA30'] = index_price.close.rolling(window=30,min_periods=1).mean() 
+            index_price.loc[:,'MA60'] = index_price.close.rolling(window=60,min_periods=1).mean() 
+            data = {
+                'data':index_price,
+                'title':title
+            }
+            return data
 
         except Exception as e:
             print(f'Failed to get data <err_msg> {e} from basic.get_ah_prem')
             return pd.DataFrame([])
 
-    def get_us_bond_rate(self, begin_date, end_date, time_para):
+    def get_us_bond_rate(self, begin_date, end_date, time_para, frequency):
         try:
             rate_dic = {
                 'US_TB_10Y':'美国十年期国债收益率',
@@ -2017,7 +2030,7 @@ class BasicDataApi(metaclass=Singleton):
             raw = RawDataApi()
             begin_date, end_date = raw.get_date_range(time_para, begin_date, end_date)
             rates = RawDataApi().get_raw_cm_index_price_df(start_date=begin_date,end_date=end_date)
-            rates = rates[['datetime','usd_central_parity_rate']].rename(columns={'usd_central_parity_rate':'美元指数'})
+            rates = rates[['datetime','usd_central_parity_rate']].rename(columns={'usd_central_parity_rate':'美元人民币汇率'})
             return rates
         except Exception as e:
             print(f'Failed to get data <err_msg> {e} from basic.get_usd_index')
