@@ -543,7 +543,7 @@ class BasicDataPart1:
                                 print(x.name, x.BENCHMARK, normalized, value_parts)
             return json.dumps({k: v for k, v in zip(r.keys(), sorted(r.values(), reverse=True))})
 
-        df = pd.read_csv(file_path, header=0, index_col=1)
+        df = pd.read_csv(file_path, header=0, index_col=0)
         r = df.apply(_parse_raw_benchmark, axis=1)
         return df, r
 
@@ -571,11 +571,12 @@ class BasicDataPart1:
         em_id_to_index_id = index_info.set_index('em_id')['index_id'].to_dict()
         all_funds_benchmark['benchmark_s_raw'] = all_funds_benchmark.apply(replaced_with_index_id, axis=1)
         now_fund_benchmark = BasicDataApi().get_fund_benchmark()
-        whole_funds_benchmark = all_funds_benchmark.join(now_fund_benchmark.set_index('em_id')[['assets', 'industry']], how='outer')
+        whole_funds_benchmark = all_funds_benchmark.join(now_fund_benchmark.set_index('em_id')[['assets', 'industry']], how='left')
         whole_funds_benchmark['benchmark_s'] = whole_funds_benchmark.benchmark_s_raw
         whole_funds_benchmark['fund_id'] = whole_funds_benchmark.apply(lambda x: x.name.split('.')[0] + '!0', axis=1)
         # TODO asset and industry
-        BasicDataHelper()._upload_basic(whole_funds_benchmark.rename_axis(index='em_id').reset_index(), FundBenchmarkNew.__table__.name)
+        BasicDataHelper()._upload_basic(whole_funds_benchmark.rename_axis(index='em_id').reset_index(), FundBenchmark.__table__.name)
+        # return whole_funds_benchmark
 
     def index_price(self, start_date, end_date):
         try:
@@ -1521,6 +1522,18 @@ class BasicDataPart1:
 
         return failed_tasks
 
+    def process_not_trading_day(self, start_date, end_date):
+        failed_tasks = []
+        
+        if not self.index_price(start_date, end_date):
+            failed_tasks.append('index_price')
+
+        if not self.fund_nav(start_date, end_date):
+            failed_tasks.append('fund_nav')
+
+        return failed_tasks
+
+
 if __name__ == '__main__':
     bdp = BasicDataPart1(BasicDataHelper())
     # start_date = '20200428'
