@@ -125,6 +125,7 @@ class DerivedDataProcessor:
                     failed_tasks.extend(self._derived_fund_score_group_1Y.process(start_date, end_date, end_date_dt))
                     failed_tasks.extend(self._derived_fund_score_group_5Y.process(start_date, end_date, end_date_dt))
                     failed_tasks.extend(self._fund_industry_exposure.process(start_date, end_date, end_date_dt))
+                    failed_tasks.extend(self._oversea_fund_nav_analysis.weekly_process(end_date))
 
                 if end_date_dt.year == next_trading_dt.year and end_date_dt.month == next_trading_dt.month:
                     # 表明本月后边还有交易日，今天不需要更新
@@ -132,7 +133,6 @@ class DerivedDataProcessor:
                 else:
                     failed_tasks.extend(self.fund_indicator_processor_monthly.process(start_date, end_date, end_date_dt))
                     failed_tasks.extend(self._manager_processor_dev.process(end_date))
-                    failed_tasks.extend(self._oversea_fund_nav_analysis.monthly_prcess(end_date))
 
         except Exception as e:
             print(e)
