@@ -506,7 +506,16 @@ class HedgeFundDataManager(metaclass=Singleton):
         other_assets = interest_receivable + deposit_in_bank
         payable_to_managers = df.at['2206', '市值.1']
         payable_to_custodian = df.at['2207', '市值.1']
-        payable_to_admin_service = df.at['2215', '市值.1']
+        for subject in ('2215', '2206.14'):
+            try:
+                payable_to_admin_service = df.at[subject, '市值.1']
+            except KeyError:
+                pass
+            else:
+                break
+        else:
+            payable_to_admin_service = np.nan
+
         nav = float(df.loc['今日单位净值', '科目名称'])
         pur_amt_receivable = np.nan
         sec_clearing_fund = np.nan
