@@ -398,6 +398,31 @@ class FundPosition:
         w_dic = { f: w / mv for f, w in w_dic.items() }
         return mv, w_dic
 
+    def calc_index_weight_by_fund_pos(self,
+                                      fund_navs: dict,
+                                      index_id=None,
+                                      is_real_trade: bool=False): # filter: 只计算某个index_id
+        mv = 0
+        index_weight = {}
+        for pos_item in self.funds.values():
+            pos_volume = pos_item.volume if not is_real_trade else pos_item.unit_volume
+            if index_id and pos_item.index_id != index_id or pos_volume == 0:
+                continue
+            nav = fund_navs.get(pos_item.fund_id, np.nan)
+            if np.isnan(nav):
+                print(f'warning!!!! nav in nan {pos_item.fund_id}')
+            else:
+                mv += nav * pos_volume
+            if pos_item.index_id not in index_weight:
+                index_weight[pos_item.index_id] = nav * pos_volume
+            else:
+                index_weight[pos_item.index_id] += nav * pos_volume
+            
+        if index_id is None:
+            mv = self.cash + mv
+        index_weight = { f: w / mv for f, w in index_weight.items() }
+        return AssetWeight(**index_weight)
+
     def calc_asset_position(self,
             fund_navs: dict,  # fund_id -> nav(adjusted net value)
             current_index_prices: AssetPrice,  # index_id -> nav(adjusted net value)
@@ -582,6 +607,7 @@ class ScoreType:
     Active:str = 'active'
     Temp:str = 'temp'
     Default:str = 'default'
+    Active2:str = 'active_2'
 
 @dataclasses.dataclass
 class ScoreSelect:
