@@ -797,7 +797,7 @@ class HedgeFundInvestorPurAndRedemp(FOFBase):
 
     id = Column(Integer, primary_key=True, autoincrement=True)
     fof_id = Column(CHAR(16), primary_key=True)  # 产品ID
-    manager_id = Column(CHAR(32))  # 管理端ID
+    manager_id = Column(CHAR(32), primary_key=True)  # 管理端ID
     datetime = Column(DATE, primary_key=True)  # 交易日期
     applied_date = Column(DATE)  # 申请日期
     deposited_date = Column(DATE)  # 交割日期
@@ -833,7 +833,7 @@ class HedgeFundInvestorDivAndCarry(FOFBase):
 
     id = Column(Integer, primary_key=True, autoincrement=True)
     fof_id = Column(CHAR(16), primary_key=True)  # 产品ID
-    manager_id = Column(CHAR(32))  # 管理端ID
+    manager_id = Column(CHAR(32), primary_key=True)  # 管理端ID
     datetime = Column(DATE, primary_key=True)  # 交易日期
     applied_date = Column(DATE)  # 申请日期
     deposited_date = Column(DATE)  # 交割日期
@@ -847,3 +847,28 @@ class HedgeFundInvestorDivAndCarry(FOFBase):
     carry_amount = Column(DOUBLE(asdecimal=False))  # 业绩报酬金额(元)
     share_changed = Column(DOUBLE(asdecimal=False), nullable=False)  # 份额变更
     share_after_trans = Column(DOUBLE(asdecimal=False), nullable=False)  # 交易后份额
+
+
+class HedgeFundCustodianData(FOFBase):
+    '''私募基金托管人数据'''
+
+    __tablename__ = 'hedge_fund_custodian_data'
+
+    id = Column(Integer, primary_key=True, autoincrement=True)
+    fof_id = Column(CHAR(16), primary_key=True)  # 产品ID
+    manager_id = Column(CHAR(32), primary_key=True)  # 管理端ID
+    datetime = Column(DATE, primary_key=True)  # 交易日期
+    nav = Column(DOUBLE(asdecimal=False), nullable=False)  # 单位净值
+    equity = Column(DOUBLE(asdecimal=False), nullable=False)  # 资产净值(元)
+    total_shares = Column(DOUBLE(asdecimal=False), nullable=False)  # 总份额
+    other_assets = Column(DOUBLE(asdecimal=False), nullable=False)  # 其他资产
+    deposit_in_bank = Column(DOUBLE(asdecimal=False))  # 银行存款
+    interest_receivable = Column(DOUBLE(asdecimal=False))  # 应收利息
+    pur_amt_receivable = Column(DOUBLE(asdecimal=False))  # 应收申购款
+    sec_clearing_fund = Column(DOUBLE(asdecimal=False))  # 证券清算款
+    dividends_receivable = Column(DOUBLE(asdecimal=False))  # 应收股利
+    payable_to_managers = Column(DOUBLE(asdecimal=False))  # 应付管理人报酬
+    payable_to_custodian = Column(DOUBLE(asdecimal=False))  # 应付托管费
+    payable_to_admin_service = Column(DOUBLE(asdecimal=False))  # 应付行政服务费
+    mutual_funds_data = Column(TEXT)  # 持仓公募信息
+    hedge_funds_data = Column(TEXT)  # 持仓私募信息
