@@ -261,7 +261,7 @@ class AssetPainter(object):
         pl.show()
 
     @staticmethod
-    def plot_index_price_ratio(df,t):
+    def plot_index_price_ratio(df,t,st_title=''):
         df.index = [str(i) for i in df.index]
         dic = ((df.iloc[-1]-1) * 10000).astype(int).to_dict()
         m = int(np.mean(list(dic.values())))
@@ -273,7 +273,7 @@ class AssetPainter(object):
                 st_1.append(f'{i[0]}:{i[1]} ')
             else:    
                 st_2.append(f'{i[0]}:{i[1]} ')
-        st = ''.join(st_1)+'\n'+''.join(st_2)
+        st = ''.join(st_1)+'\n'+''.join(st_2)+'\n' + st_title
         df.plot.line(figsize=(14,8),fontsize=15)
         plt.legend(fontsize=13, loc='lower left')
         plt.title(t,fontsize=22)
