@@ -146,14 +146,24 @@ class CalculatorBase:
         days = (dates[-1] - dates[0]).days
         history_annual_ret = math.pow(history_ret + 1, CalculatorBase.TOTAL_DAYS_PER_YEAR/days) - 1
         sr_week = CalculatorBase.data_resample_weekly_nav(sr,rule='W-FRI')
-        recent_4w_ret=sr_week[-1] / sr_week[-5] - 1
-        
+        if sr_week.shape[0] < 5:
+            recent_4w_ret = sr_week[-1] / sr_week[0] - 1
+        else:
+            recent_4w_ret = sr_week[-1] / sr_week[-5] - 1
+
         _date_20_b = datetime.date(2019,12,31)
         _date_20_e = datetime.date(2020,12,31)
         date_20_b = max(sr.index.min(),_date_20_b)
         date_20_e = min(sr.index.max(),_date_20_e)
         _sr = sr[date_20_b:date_20_e]
         y_2020_ret = _sr[-1] / _sr[0] - 1 if not _sr.empty else None
+        lasty_year = sr.index[-1].year - 1
+        _date_last_b = datetime.date(lasty_year-1,12,31)
+        _date_last_e = datetime.date(lasty_year,12,31)
+        date_last_b = max(sr.index.min(),_date_last_b)
+        date_last_e = min(sr.index.max(),_date_last_e)
+        _sr = sr[date_last_b:date_last_e]
+        y_last_ret = _sr[-1] / _sr[0] - 1 if not _sr.empty else None
         return {
             'recent_natural_year_ret':recent_natural_year_ret,
             'recent_1w_ret':recent_1w_ret,
@@ -169,6 +179,7 @@ class CalculatorBase:
             'history_ret':history_ret,
             'history_annual_ret':history_annual_ret,
             'y_2020_ret':y_2020_ret,
+            'last_year_ret':y_last_ret,
         }
 
     @staticmethod
@@ -394,6 +405,7 @@ class CalculatorBase:
             recent_3y_ret = recent_ret_res['recent_3y_ret']
             recent_5y_ret = recent_ret_res['recent_5y_ret']
             recent_4w_ret = recent_ret_res['recent_4w_ret']
+            last_year_ret = recent_ret_res['last_year_ret']
             y_2020_ret = recent_ret_res['y_2020_ret']
             worst_3m_ret = sr.pct_change(period_3m).min()
             worst_6m_ret = sr.pct_change(period_6m).min()
@@ -536,6 +548,7 @@ class CalculatorBase:
                     'recent_1m_ret':recent_1m_ret,
                     'recent_4w_ret':recent_4w_ret,
                     'y_2020_ret':y_2020_ret,
+                    'last_year_ret':last_year_ret,
                     'recent_3m_ret':recent_3m_ret,
                     'recent_6m_ret':recent_6m_ret,
                     'recent_1y_ret':recent_1y_ret,
@@ -606,6 +619,7 @@ class CalculatorBase:
                     'recent_1m_ret':recent_1m_ret,
                     'recent_4w_ret':recent_4w_ret,
                     'y_2020_ret':y_2020_ret,
+                    'last_year_ret':last_year_ret,
                     'recent_3m_ret':recent_3m_ret,
                     'recent_6m_ret':recent_6m_ret,
                     'recent_1y_ret':recent_1y_ret,
@@ -648,6 +662,7 @@ class CalculatorBase:
                     'recent_1m_ret':0,
                     'recent_4w_ret':0,
                     'y_2020_ret':0,
+                    'last_year_ret':0,
                     'recent_3m_ret':0,
                     'recent_6m_ret':0,
                     'recent_1y_ret':0,
